==> lxqt-session-0.14.0.tar.xz: lxqt-session-0.14.0/lxqt-leave/translations/lxqt-leave_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation type="unfinished">Napusti</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Što želite da računalo učini?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="51"/>
        <source>Logout</source>
        <translation type="unfinished">Odjava</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="69"/>
        <source>Reboot</source>
        <translation type="unfinished">Ponovno podizanje</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="56"/>
        <source>Shutdown</source>
        <translation type="unfinished">Isključivanje</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Suspend</source>
        <translation type="unfinished">suspenzija</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Lock screen</source>
        <translation type="unfinished">Zaključavanje zaslona</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="74"/>
        <source>Hibernate</source>
        <translation type="unfinished">Hibernacija</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation type="unfinished">Otkaži</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Logout.</source>
        <translation type="unfinished">Odjava.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Lockscreen.</source>
        <translation type="unfinished">Zaključaj zaslon.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Suspend.</source>
        <translation type="unfinished">Suspendiraj.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Hibernate.</source>
        <translation type="unfinished">Hibernacija.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Shutdown.</source>
        <translation type="unfinished">Isključi.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Reboot.</source>
        <translation type="unfinished">Ponovno podigni.</translation>
    </message>
</context>
</TS>

==> lxqt-session-0.15.0.tar.xz: lxqt-session-0.15.0/lxqt-leave/translations/lxqt-leave_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Napusti</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Što želite da računalo učini?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="51"/>
        <source>Logout</source>
        <translation>Odjava</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="69"/>
        <source>Reboot</source>
        <translation>Ponovno pokretanje</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="56"/>
        <source>Shutdown</source>
        <translation>Isključivanje</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Suspend</source>
        <translation>Suspenzija</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Lock screen</source>
        <translation>Zaključavanje zaslona</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="74"/>
        <source>Hibernate</source>
        <translation>Hibernacija</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Otkaži</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Logout.</source>
        <translation>Odjava.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Lockscreen.</source>
        <translation>Zaslon zaključavanja.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Suspend.</source>
        <translation>Suspendiraj.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Hibernate.</source>
        <translation>Hibernacija.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Shutdown.</source>
        <translation>Isključi.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Reboot.</source>
        <translation>Ponovno pokreni.</translation>
    </message>
</context>
</TS>
